==> 0.1.2.tar.gz: lib/src/icons.dart <==
library adinkra_icons;

class AdinkraIcons {
  const AdinkraIcons._(this.name);

  final String name;

  //Aban icon
  static const aban = AdinkraIcons._('aban');

  //Abe-Dua icon
  static const abeDua = AdinkraIcons._('abe-dua');

  //Adinkrahene icon
  static const adinkrahene = AdinkraIcons._('adinkrahene');

  //Adwo icon
  static const adwo = AdinkraIcons._('adwo');

  //Agyindawuru icon
  static const agyindawuru = AdinkraIcons._('agyindawuru');

  //Akoben icon
  static const akoben = AdinkraIcons._('akoben');

  //Akofena icon
  static const akofena = AdinkraIcons._('akofena');

  //Akoko-Nan icon
  static const akokoNan = AdinkraIcons._('akoko-nan');

  //Akoma-Ntoso icon
  static const akomaNtoso = AdinkraIcons._('akoma-ntoso');

  //Akoma icon
  static const akoma = AdinkraIcons._('akoma');

  //Ananse-Ntontan icon
  static const ananseNtontan = AdinkraIcons._('ananse-ntontan');

  //Ani-Bere-A-Enso-Gya icon
  static const aniBereAEnsoGya = AdinkraIcons._('ani-bere-a-enso-gya');

  //Asase-Ye-duru icon
  static const asaseYeDuru = AdinkraIcons._('asase-ye-duru');

  //Aya icon
  static const aya = AdinkraIcons._('aya');

  //Bese-saka icon
  static const beseSaka = AdinkraIcons._('bese-saka');

  //Bi-Nka-Bi icon
  static const biNkaBi = AdinkraIcons._('bi-nka-bi');

  //Boa-Me-Na-Me-Mmoa-Wo icon
  static const boaMeNaMeMmoaWo = AdinkraIcons._('boa-me-na-me-mmoa-wo');

  //Dame-Dame icon
  static const dameDame = AdinkraIcons._('dame-dame');

  //Denkyem icon
  static const denkyem = AdinkraIcons._('denkyem');

  //Dono-Ntoaso icon
  static const donoNtoaso = AdinkraIcons._('dono-ntoaso');

  //Dono icon
  static const dono = AdinkraIcons._('dono');

  //Duafe icon
  static const duafe = AdinkraIcons._('duafe');

  //Dwennimmen icon
  static const dwennimmen = AdinkraIcons._('dwennimmen');

  //Eban icon
  static const eban = AdinkraIcons._('eban');

  //Epa icon
  static const epa = AdinkraIcons._('epa');

  //Ese-Ne-Tekrema icon
  static const eseNeTekrema = AdinkraIcons._('ese-ne-tekrema');

  //Fafanto icon
  static const fafanto = AdinkraIcons._('fafanto');

  //Fawohodie icon
  static const fawohodie = AdinkraIcons._('fawohodie');

  //Fihankra icon
  static const fihankra = AdinkraIcons._('fihankra');

  //Fofo icon
  static const fofo = AdinkraIcons._('fofo');

  //Funtunfunefu-Denkyemfunefu icon
  static const funtunfunefuDenkyemfunefu = AdinkraIcons._('funtunfunefu-denkyemfunefu');

  //Gye-Nyame icon
  static const gyeNyame = AdinkraIcons._('gye-nyame');

  //Hwe-Mu-Dua icon
  static const hweMuDua = AdinkraIcons._('hwe-mu-dua');

  //Hye-Won-Hye icon
  static const hyeWonHye = AdinkraIcons._('hye-won-hye');

  //Kete-Pa icon
  static const ketePa = AdinkraIcons._('kete-pa');

  //Kintinkantan icon
  static const kintinkantan = AdinkraIcons._('kintinkantan');

  //Kramo-Bone-Amma-Yeanhu-Kramo-Pa icon
  static const kramoBoneAmmaYeanhuKramoPa = AdinkraIcons._('kramo-bone-amma-yeanhu-kramo-pa');

  //Kuronti-Ne-Akwamu icon
  static const kurontiNeAkwamu = AdinkraIcons._('kuronti-ne-akwamu');

  //Kwatakye-Atiko icon
  static const kwatakyeAtiko = AdinkraIcons._('kwatakye-atiko');

  //Mako icon
  static const mako = AdinkraIcons._('mako');

  //Mate-Masie icon
  static const mateMasie = AdinkraIcons._('mate-masie');

  //Me-Ware-Wo icon
  static const meWareWo = AdinkraIcons._('me-ware-wo');

  //Menso-Wo-Kenten icon 
  static const mensoWoKenten = AdinkraIcons._('menso-wo-kenten');

  //Mframadan icon
  static const mframadan = AdinkraIcons._('mframadan');

  //Mmere-Dane icon
  static const mmereDane = AdinkraIcons._('mmere-dane');

  //Mmusuyidee icon
  static const mmusuyidee = AdinkraIcons._('mmusuyidee');

  //Mpatapo icon
  static const mpatapo = AdinkraIcons._('mpatapo');

  //Mpuannum icon
  static const mpuannum = AdinkraIcons._('mpuannum');

  //Nea-Onnim icon
  static const neaOnnim = AdinkraIcons._('nea-onnim');

  //Nea-Ope-Se-Obedi-Hene icon
  static const neaOpeSeObediHene = AdinkraIcons._('nea-ope-se-obedi-hene');

  //Nkonsonkonson icon
  static const nkonsonkonson = AdinkraIcons._('nkonsonkonson');

  //Nkyimu icon
  static const nkyimu = AdinkraIcons._('nkyimu');

  //Nkyinkyim icon
  static const nkyinkyim = AdinkraIcons._('nkyinkyim');

  //Nsaa icon
  static const nsaa = AdinkraIcons._('nsaa');

  //Nsoromma icon
  static const nsoromma = AdinkraIcons._('nsoromma');

  //Nteasee icon
  static const nteasee = AdinkraIcons._('nteasee');

  //Nyame-Biribi-Wo-Soro icon
  static const nyameBiribiWoSoro = AdinkraIcons._('nyame-biribi-wo-soro');

  //Nyame-Dua icon
  static const nyameDua = AdinkraIcons._('nyame-dua');

  //Nyame-Nnwu-Na-Mawu icon
  static const nyameNnwuNaMawu = AdinkraIcons._('nyame-nnwu-na-mawu');

  //Nyame-Nti icon
  static const nyameNti = AdinkraIcons._('nyame-nti');

  //Nyame-Ye-Ohene icon
  static const nyameYeOhene = AdinkraIcons._('nyame-ye-ohene');

  //Nyansapo icon
  static const nyansapo = AdinkraIcons._('nyansapo');

  //Odo-Nyera-Fie-Kwan icon
  static const odoNyeraFieKwan = AdinkraIcons._('odo-nyera-fie-kwan');

  //Okodee-Mmowere icon
  static const okodeeMmowere = AdinkraIcons._('okodee-mmowere');

  //Okuafo-Pa icon
  static const okuafoPa = AdinkraIcons._('okuafo-pa');

  //Onyankopon-Adom-Nti-Biribiara-Beye-Yie icon
  static const onyankoponAdomNtiBiribiaraBeyeYie = AdinkraIcons._('onyankopon-adom-nti-biribiara-beye-yie');

  //Osram-Ne-Nsoromma icon
  static const osramNeNsoromma = AdinkraIcons._('osram-ne-nsoromma');

  //Owo-Foro-Adobe icon
  static const owoForoAdobe = AdinkraIcons._('owo-foro-adobe');

  //Owuo-Atwedee icon
  static const owuoAtwedee = AdinkraIcons._('owuo-atwedee');

  //Pempamsie icon
  static const pempamsie = AdinkraIcons._('pempamsie');

  //Sankofa-One icon
  static const sankofaOne = AdinkraIcons._('sankofa-one');

  //Sankofa-Two icon
  static const sankofaTwo = AdinkraIcons._('sankofa-two');

  //Sepow icon
  static const sepow = AdinkraIcons._('sepow');

  //Sesa-Wo-Suban icon
  static const sesaWoSuban = AdinkraIcons._('sesa-wo-suban');

  //Tamfo-Bebre icon
  static const tamfoBebre = AdinkraIcons._('tamfo-bebre');

  //Uac-Nkanea icon
  static const uacNkanea = AdinkraIcons._('uac-nkanea');

  //Wawa-Aba icon
  static const wawaAba = AdinkraIcons._('wawa-aba');

  //Wo-Nsa-Da-Mu icon
  static const woNsaDaMu = AdinkraIcons._('wo-nsa-da-mu');

  //Woforo-Dua icon
  static const woforoDua = AdinkraIcons._('woforo-dua');

}

==> 0.1.4.tar.gz: lib/src/icons.dart <==
library adinkra_icons;

class AdinkraIcons {
  const AdinkraIcons._(this.name);

  final String name;

  //Aban icon
  static const aban = AdinkraIcons._('aban');

  //Abe-Dua icon
  static const abeDua = AdinkraIcons._('abe-dua');

  //Abusua-Pa icon
  static const abusuaPa = AdinkraIcons._('abusua-pa');

  //Adinkrahene icon
  static const adinkrahene = AdinkraIcons._('adinkrahene');

  //Adwo icon
  static const adwo = AdinkraIcons._('adwo');

  //Agyindawuru icon
  static const agyindawuru = AdinkraIcons._('agyindawuru');

  //Akoben icon
  static const akoben = AdinkraIcons._('akoben');

  //Akofena icon
  static const akofena = AdinkraIcons._('akofena');

  //Akoko-Nan icon
  static const akokoNan = AdinkraIcons._('akoko-nan');

  //Akoma-Ntoso icon
  static const akomaNtoso = AdinkraIcons._('akoma-ntoso');

  //Akoma icon
  static const akoma = AdinkraIcons._('akoma');

  //Ananse-Ntontan icon
  static const ananseNtontan = AdinkraIcons._('ananse-ntontan');

  //Ani-Bere-A-Enso-Gya icon
  static const aniBereAEnsoGya = AdinkraIcons._('ani-bere-a-enso-gya');

  //Anyi-Me-Aye-A icon
  static const anyiMeAyeA = AdinkraIcons._('anyi-me-aye-a');

  //Asaawa icon
  static const asaawa = AdinkraIcons._('asaawa');

  //Asase-Ye-duru icon
  static const asaseYeDuru = AdinkraIcons._('asase-ye-duru');

  //Asetena Pa icon
  static const asetenaPa = AdinkraIcons._('asetena-pa');

  //Awurade-Baatanfo icon
  static const awuradeBaatanfo = AdinkraIcons._('awurade-baatanfo');

  //Aya icon
  static const aya = AdinkraIcons._('aya');

  //Bese-saka icon
  static const beseSaka = AdinkraIcons._('bese-saka');

  //Bi-Nka-Bi icon
  static const biNkaBi = AdinkraIcons._('bi-nka-bi');

  //Boa-Me-Na-Me-Mmoa-Wo icon
  static const boaMeNaMeMmoaWo = AdinkraIcons._('boa-me-na-me-mmoa-wo');

  //Boafo-Ye-Na icon
  static const boafoYeNa = AdinkraIcons._('boafo-ye-na');

  //Dame-Dame icon
  static const dameDame = AdinkraIcons._('dame-dame');

  //Denkyem icon
  static const denkyem = AdinkraIcons._('denkyem');

  //Dono-Ntoaso icon
  static const donoNtoaso = AdinkraIcons._('dono-ntoaso');

  //Dono icon
  static const dono = AdinkraIcons._('dono');

  //Duafe icon
  static const duafe = AdinkraIcons._('duafe');

  //Dwennimmen icon
  static const dwennimmen = AdinkraIcons._('dwennimmen');

  //Eban icon
  static const eban = AdinkraIcons._('eban');

  //Epa icon
  static const epa = AdinkraIcons._('epa');

  //Ese-Ne-Tekrema icon
  static const eseNeTekrema = AdinkraIcons._('ese-ne-tekrema');

  //Esono-Anantam icon
  static const esonoAnantam = AdinkraIcons._('esono-anantam');

  //Fafanto icon
  static const fafanto = AdinkraIcons._('fafanto');

  //Fawohodie icon
  static const fawohodie = AdinkraIcons._('fawohodie');

  //Fihankra icon
  static const fihankra = AdinkraIcons._('fihankra');

  //Fofo icon
  static const fofo = AdinkraIcons._('fofo');

  //Funtunfunefu-Denkyemfunefu icon
  static const funtunfunefuDenkyemfunefu =
      AdinkraIcons._('funtunfunefu-denkyemfunefu');

  //Gye-W'ani icon
  static const gyeWAni = AdinkraIcons._('gye-w-ani');

  //Gye-Nyame icon
  static const gyeNyame = AdinkraIcons._('gye-nyame');

  //Hwe-Mu-Dua icon
  static const hweMuDua = AdinkraIcons._('hwe-mu-dua');

  //Hye-Won-Hye icon
  static const hyeWonHye = AdinkraIcons._('hye-won-hye');

  //Kete-Pa icon
  static const ketePa = AdinkraIcons._('kete-pa');

  //Kintinkantan icon
  static const kintinkantan = AdinkraIcons._('kintinkantan');

  //Kokuromotie icon
  static const kokuromotie = AdinkraIcons._('kokuromotie');

  //Kramo-Bone-Amma-Yeanhu-Kramo-Pa icon
  static const kramoBoneAmmaYeanhuKramoPa =
      AdinkraIcons._('kramo-bone-amma-yeanhu-kramo-pa');

  //Kuronti-Ne-Akwamu icon
  static const kurontiNeAkwamu = AdinkraIcons._('kuronti-ne-akwamu');

  //Kwatakye-Atiko icon
  static const kwatakyeAtiko = AdinkraIcons._('kwatakye-atiko');

  //Kyemfere icon
  static const kyemfere = AdinkraIcons._('kyemfere');

  //Mako icon
  static const mako = AdinkraIcons._('mako');

  //Mate-Masie icon
  static const mateMasie = AdinkraIcons._('mate-masie');

  //Me-Ware-Wo icon
  static const meWareWo = AdinkraIcons._('me-ware-wo');

  //Mekyia Wo icon
  static const mekyiaWo = AdinkraIcons._('mekyia-wo');

  //Menso-Wo-Kenten icon
  static const mensoWoKenten = AdinkraIcons._('menso-wo-kenten');

  //Mframadan icon
  static const mframadan = AdinkraIcons._('mframadan');

  //Mmere-Dane icon
  static const mmereDane = AdinkraIcons._('mmere-dane');

  //Mmusuyidee icon
  static const mmusuyidee = AdinkraIcons._('mmusuyidee');

  //Mo-No-Yo icon
  static const moNoYo = AdinkraIcons._('mo-no-yo');

  //Mpatapo icon
  static const mpatapo = AdinkraIcons._('mpatapo');

  //Mpuannum icon
  static const mpuannum = AdinkraIcons._('mpuannum');

  //Mrammuo icon
  static const mrammuo = AdinkraIcons._('mrammuo');

  //Nante-Yie icon
  static const nanteYie = AdinkraIcons._('nante-yie');

  //Nea-Onnim icon
  static const neaOnnim = AdinkraIcons._('nea-onnim');

  //Nea-Ope-Se-Obedi-Hene icon
  static const neaOpeSeObediHene = AdinkraIcons._('nea-ope-se-obedi-hene');

  //Nkonsonkonson icon
  static const nkonsonkonson = AdinkraIcons._('nkonsonkonson');

  //Nkotimsefo-Mpua icon
  static const nkotimsefo = AdinkraIcons._('nkotimsefo-mpua');

  //Nkrabea icon
  static const nkrabea = AdinkraIcons._('nkrabea');

  //Nkyimu icon
  static const nkyimu = AdinkraIcons._('nkyimu');

  //Nkyinkyim icon
  static const nkyinkyim = AdinkraIcons._('nkyinkyim');

  //Nnampo Pa Baanu icon
  static const nnampoPaBaanu = AdinkraIcons._('nnampo-pa-baanu');

  //Nokore icon
  static const nokore = AdinkraIcons._('nokore');

  //Nsaa icon
  static const nsaa = AdinkraIcons._('nsaa');

  //Nserewa icon
  static const nserewa = AdinkraIcons._('nserewa');

  //Nsoromma icon
  static const nsoromma = AdinkraIcons._('nsoromma');

  //Nteasee icon
  static const nteasee = AdinkraIcons._('nteasee');

  //Nya-Gyidie icon
  static const nyaGyidie = AdinkraIcons._('nya-gyidie');

  //Nyame-Biribi-Wo-Soro icon
  static const nyameBiribiWoSoro = AdinkraIcons._('nyame-biribi-wo-soro');

  //Nyame-Dua icon
  static const nyameDua = AdinkraIcons._('nyame-dua');

  //Nyame-Nnwu-Na-Mawu icon
  static const nyameNnwuNaMawu = AdinkraIcons._('nyame-nnwu-na-mawu');

  //Nyame-Nti icon
  static const nyameNti = AdinkraIcons._('nyame-nti');

  //Nyame-Ye-Ohene icon
  static const nyameYeOhene = AdinkraIcons._('nyame-ye-ohene');

  //Nyansapo icon
  static const nyansapo = AdinkraIcons._('nyansapo');

  //Obohemmaa icon
  static const obohemmaa = AdinkraIcons._('obohemmaa');

  //Odo-Nyera-Fie-Kwan icon
  static const odoNyeraFieKwan = AdinkraIcons._('odo-nyera-fie-kwan');

  //Okodee-Mmowere icon
  static const okodeeMmowere = AdinkraIcons._('okodee-mmowere');

  //Okuafo-Pa icon
  static const okuafoPa = AdinkraIcons._('okuafo-pa');

  //Onyankopon-Adom-Nti-Biribiara-Beye-Yie icon
  static const onyankoponAdomNtiBiribiaraBeyeYie =
      AdinkraIcons._('onyankopon-adom-nti-biribiara-beye-yie');

  //Osram-Ne-Nsoromma icon
  static const osramNeNsoromma = AdinkraIcons._('osram-ne-nsoromma');

  //Owo-Foro-Adobe icon
  static const owoForoAdobe = AdinkraIcons._('owo-foro-adobe');

  //Owuo-Atwedee icon
  static const owuoAtwedee = AdinkraIcons._('owuo-atwedee');

  //Pempamsie icon
  static const pempamsie = AdinkraIcons._('pempamsie');

  //Sankofa-One icon
  static const sankofaOne = AdinkraIcons._('sankofa-one');

  //Sankofa-Two icon
  static const sankofaTwo = AdinkraIcons._('sankofa-two');

  //Sepow icon
  static const sepow = AdinkraIcons._('sepow');

  //Sesa-Wo-Suban icon
  static const sesaWoSuban = AdinkraIcons._('sesa-wo-suban');

  //Som Onyankopon icon
  static const somOnyankopon = AdinkraIcons._('som-onyankopon');

  //Sunsum icon
  static const sunsum = AdinkraIcons._('sunsum');

  //Tabono icon
  static const tabono = AdinkraIcons._('tabono');

  //Tamfo-Bebre icon
  static const tamfoBebre = AdinkraIcons._('tamfo-bebre');

  //Uac-Nkanea icon
  static const uacNkanea = AdinkraIcons._('uac-nkanea');

  //Wawa-Aba icon
  static const wawaAba = AdinkraIcons._('wawa-aba');

  //Wo-Nsa-Da-Mu icon
  static const woNsaDaMu = AdinkraIcons._('wo-nsa-da-mu');

  //Woforo-Dua icon
  static const woforoDua = AdinkraIcons._('woforo-dua');
}
